from typing import Mapping, Sequence, Tuple

weather_rate: Mapping[int, Sequence[Tuple[int, int]]] = {
    0: [(100, 2)],
    1: [(5, 7), (20, 7), (30, 4), (40, 3), (55, 2), (85, 1), (100, 2)],
    2: [(5, 7), (20, 7), (30, 4), (40, 3), (55, 2), (85, 1), (100, 2)],
    3: [(5, 9), (20, 7), (30, 4), (40, 3), (55, 2), (85, 1), (100, 2)],
    4: [(5, 9), (20, 7), (30, 4), (40, 3), (55, 2), (85, 1), (100, 2)],
    5: [(5, 4), (10, 10), (25, 9), (30, 4), (40, 3), (70, 2), (100, 1)],
    6: [(5, 4), (10, 8), (25, 7), (30, 4), (40, 3), (70, 2), (100, 1)],
    7: [(40, 1), (60, 2), (85, 3), (95, 4), (100, 7)],
    8: [(40, 1), (60, 2), (85, 3), (95, 4), (100, 7)],
    9: [(40, 1), (60, 2), (85, 3), (95, 4), (100, 7)],
    10: [(15, 11), (55, 1), (75, 2), (85, 3), (95, 4), (100, 7)],
    11: [(40, 1), (60, 2), (70, 3), (80, 4), (85, 7), (100, 8)],
    12: [(20, 14), (60, 1), (80, 2), (90, 3), (100, 4)],
    13: [(5, 1), (20, 2), (50, 3), (100, 4)],
    14: [(20, 3), (50, 1), (80, 2), (90, 4), (100, 7)],
    15: [(20, 3), (50, 1), (80, 2), (90, 4), (100, 7)],
    16: [(20, 3), (50, 1), (70, 2), (80, 5), (90, 4), (100, 7)],
    17: [(20, 3), (50, 1), (70, 2), (80, 5), (90, 4), (100, 7)],
    18: [(5, 4), (50, 1), (80, 2), (90, 3), (95, 7), (100, 8)],
    19: [(10, 4), (40, 1), (60, 2), (80, 3), (90, 5), (100, 6)],
    20: [(30, 1), (50, 2), (70, 3), (80, 4), (90, 9), (100, 10)],
    21: [(20, 16), (60, 15), (70, 2), (75, 1), (90, 3), (100, 4)],
    22: [(15, 3), (30, 4), (60, 17), (75, 1), (100, 2)],
    23: [(100, 29)],
    24: [(30, 1), (50, 2), (70, 3), (85, 4), (100, 7)],
    25: [(100, 26)],
    26: [(100, 28)],
    27: [(100, 15)],
    28: [(100, 3)],
    29: [(20, 3), (50, 1), (80, 2), (90, 4), (100, 10)],
    30: [(100, 27)],
    31: [(100, 25)],
    32: [(20, 3), (50, 1), (70, 2), (80, 2), (90, 4), (100, 7)],
    33: [(40, 1), (60, 2), (85, 3), (95, 4), (100, 7)],
    34: [(5, 3), (20, 7), (30, 4), (40, 3), (55, 2), (85, 1), (100, 2)],
    35: [(100, 15)],
    36: [(100, 5)],
    37: [(100, 9)],
    38: [(100, 23)],
    39: [(100, 24)],
    40: [(100, 4)],
    41: [(100, 11)],
    42: [(100, 16)],
    43: [(100, 22)],
    44: [(100, 36)],
    45: [(100, 20)],
    46: [(100, 35)],
    47: [(60, 15), (70, 2), (75, 1), (90, 3), (100, 4)],
    48: [(60, 15), (70, 2), (75, 1), (90, 3), (100, 4)],
    49: [(20, 16), (60, 15), (70, 2), (75, 1), (90, 3), (100, 4)],
    50: [(10, 3), (20, 4), (30, 9), (40, 11), (70, 1), (100, 2)],
    51: [(10, 3), (20, 4), (30, 7), (40, 8), (70, 1), (100, 2)],
    52: [(10, 3), (20, 6), (40, 50), (70, 1), (100, 2)],
    53: [(30, 1), (60, 2), (70, 3), (80, 4), (90, 5), (100, 49)],
    54: [(35, 2), (70, 3), (100, 9)],
    55: [(10, 3), (20, 4), (30, 7), (40, 8), (70, 1), (100, 2)],
    56: [(100, 44)],
    57: [(100, 51)],
    58: [(100, 1)],
    59: [(15, 4), (40, 7), (100, 2)],
    60: [(40, 2), (75, 4), (95, 5), (99, 49), (100, 54)],
    61: [(40, 2), (60, 4), (95, 5), (99, 49), (100, 54)],
    62: [(40, 2), (65, 4), (90, 5), (98, 49), (100, 54)],
    63: [(100, 7)],
    64: [(60, 2), (100, 7)],
    65: [(50, 2), (100, 7)],
    66: [(100, 60)],
    67: [(35, 2), (65, 15), (85, 16), (100, 4)],
    68: [(100, 14)],
    69: [(100, 69)],
    70: [(100, 54)],
    71: [(30, 2), (60, 4), (90, 5), (100, 49)],
    72: [(65, 2), (100, 7)],
    73: [(65, 2), (100, 7)],
    74: [(100, 17)],
    75: [(100, 74)],
    76: [(100, 84)],
    77: [(100, 80)],
    78: [(15, 1), (60, 2), (80, 3), (90, 4), (100, 9)],
    79: [(15, 1), (60, 2), (80, 3), (90, 4), (100, 9)],
    80: [(10, 1), (60, 2), (75, 3), (85, 4), (95, 5), (100, 11)],
    81: [(20, 1), (60, 2), (80, 3), (90, 4), (100, 10)],
    82: [(10, 7), (20, 4), (40, 3), (80, 2), (100, 1)],
    83: [(10, 9), (20, 5), (35, 3), (75, 2), (100, 1)],
    84: [(5, 8), (15, 7), (25, 4), (40, 3), (80, 2), (100, 1)],
    85: [(5, 6), (10, 5), (17, 7), (25, 4), (35, 3), (75, 2), (100, 1)],
    86: [(100, 50)],
    87: [(100, 82)],
    88: [(100, 79)],
    89: [(100, 88)],
    90: [(100, 2)],
    91: [(30, 2), (60, 6), (90, 8), (100, 15)],
    92: [(100, 77)],
    93: [(100, 92)],
    94: [(10, 2), (28, 4), (46, 14), (64, 15), (82, 9), (100, 16)],
    95: [(100, 101)],
    96: [(10, 2), (28, 14), (46, 9), (64, 16), (82, 49), (100, 15)],
    97: [(100, 12)],
    98: [(100, 102)],
    99: [(100, 113)],
    100: [(12, 2), (34, 8), (56, 17), (78, 10), (100, 15)],
    101: [(100, 119)],
    102: [(100, 118)],
    103: [(100, 122)],
    104: [(100, 125)],
    105: [(100, 120)],
    106: [(20, 1), (60, 2), (75, 3), (85, 4), (95, 7), (100, 10)],
    107: [(10, 6), (20, 7), (30, 4), (45, 3), (85, 2), (100, 1)],
    108: [(45, 2), (60, 3), (70, 11), (80, 14), (100, 1)],
    109: [(10, 7), (20, 4), (35, 3), (45, 10), (60, 1), (100, 2)],
    110: [(10, 4), (20, 7), (30, 49), (45, 1), (85, 2), (100, 3)],
    111: [(20, 3), (80, 2), (100, 1)],
    112: [(20, 1), (60, 2), (75, 3), (85, 4), (95, 7), (100, 10)],
    113: [(10, 6), (20, 7), (30, 4), (45, 3), (85, 2), (100, 1)],
    114: [(100, 105)],
    115: [(100, 10)],
    116: [(100, 127)],
    117: [(50, 2), (80, 5), (90, 7), (95, 6), (100, 4)],
    118: [(50, 1), (100, 2)],
    119: [(45, 2), (63, 3), (80, 4), (95, 7), (100, 8)],
    120: [(40, 2), (55, 3), (70, 4), (95, 5), (100, 6)],
    121: [(35, 2), (50, 3), (65, 4), (85, 15), (100, 16)],
    122: [(82, 2), (87, 3), (92, 4), (97, 11), (100, 14)],
    123: [(100, 138)],
    124: [(52, 2), (64, 7), (76, 5), (88, 9), (100, 11)],
    125: [(100, 137)],
    126: [(100, 147)],
    127: [(50, 2), (65, 3), (80, 4), (95, 9), (100, 10)],
    128: [(40, 2), (58, 3), (75, 4), (93, 7), (100, 8)],
    129: [(44, 2), (59, 3), (73, 4), (93, 9), (100, 10)],
    130: [(60, 2), (70, 7), (80, 5), (90, 9), (100, 15)],
    131: [(15, 1), (60, 2), (85, 3), (100, 7)],
    132: [(10, 4), (20, 7), (25, 8), (40, 1), (80, 2), (100, 3)],
    133: [(45, 15), (50, 9), (55, 7), (60, 4), (85, 3), (95, 2), (100, 1)],
    134: [(25, 3), (40, 49), (85, 2), (100, 1)],
    135: [(15, 49), (30, 148), (100, 2)],
    136: [(15, 149), (85, 2), (100, 49)],
    137: [(10, 1), (50, 2), (70, 3), (85, 4), (100, 15)],
    138: [(10, 4), (25, 7), (40, 1), (80, 2), (100, 3)],
    139: [(100, 151)],
    140: [(100, 156)],
    141: [(100, 150)],
    142: [(5, 15), (25, 2), (65, 1), (80, 3), (90, 4)],
    143: [(100, 160)],
    144: [(100, 161)],
    145: [(100, 157)],
    146: [(100, 128)],
    147: [(100, 162)],
    148: [(25, 1), (70, 2), (80, 3), (90, 7), (95, 4), (100, 8)],
    149: [(100, 171)],
    150: [],
    151: [],
    152: [],
    153: [],
    154: [],
    155: [],
    156: [],
    157: [],
    158: [],
    159: [],
    160: []
}
